<?php
/**
 * @file
 * Acton Profile theme declaration and processing functions.
 */

/**
 * Defines theme hooks.
 */
function _acton_profile_theme($existing, $type, $theme, $path) {
  $base = array(
    'path' => drupal_get_path('module', 'acton_profile') . '/theme',
    'file' => 'acton_profile.theme.inc',
  );

  // Define profile hooks.
  $hooks['acton_anu_head'] = array(
    'variables' => array('profile' => NULL),
  ) + $base;
  $hooks['acton_anu_body_header'] = array(
    'variables' => array('profile' => NULL, 'tabs' => array()),
  ) + $base;
  $hooks['acton_anu_body_footer'] = array(
    'variables' => array('profile' => NULL),
  ) + $base;
  $hooks['acton_page_requisite'] = array(
    'variables' => array('profile' => NULL, 'part' => ''),
  ) + $base;

  // Define template hooks.
  $hooks['acton_head'] = array(
    'variables' => array(
      'identifier' => '',
      'title' => '',
      'description' => '',
      'subject' => '',
      'date_modified' => '',
      'creator' => '',
      'creator_address' => '',
    ),
    'template' => 'acton-head',
  ) + $base;
  $hooks['acton_alert_bar'] = array(
    'variables' => array('message' => ''),
    'template' => 'acton-alert-bar',
  ) + $base;
  $hooks['acton_banner_tabs'] = array(
    'variables' => array('links' => array()),
    'template' => 'acton-banner-tabs',
  ) + $base;
  $hooks['acton_responsive_menu'] = array(
    'variables' => array('menu_icon_src' => '', 'search_box_mini' => array()),
    'template' => 'acton-responsive-menu',
  ) + $base;
  $hooks['acton_search_box'] = array(
    'variables' => array('site_short_name' => '', 'search_base' => array(), 'advanced' => TRUE),
    'template' => 'acton-search-box',
  ) + $base;
  $hooks['acton_search_box_mini'] = array(
    'variables' => array('search_base' => array()),
    'template' => 'acton-search-box-mini',
  ) + $base;
  $hooks['acton_site_footer'] = array(
    'variables' => array(
      'resp_officer' => '',
      'resp_officer_address' => '',
      'site_contact' => '',
      'site_contact_address' => '',
      'date_modified' => '',
      'about_page' => '',
    ),
    'template' => 'acton-site-footer',
  ) + $base;

  // Define legacy deprecated hooks.
  $hooks += _acton_profile_legacy_theme();

  return $hooks;
}

/**
 * Implements hook_preprocess_acton_page_requisite().
 */
function template_preprocess_acton_page_requisite(&$variables) {
  if ($variables['part']) {
    // Add template suggestion.
    $variables['theme_hook_suggestions'][] = 'acton_page_requisite__' . $variables['part'];
  }
}

/**
 * Renders a page part.
 */
function theme_acton_page_requisite($variables) {
  // Retrieve style part.
  if ($profile = $variables['profile']) {
    $controller = acton_profile_style_controller();
    if ($controller instanceof ActonProfileStyleControllerInterface) {
      $backend = $controller->getBackend($profile);
      if ($backend instanceof ActonProfileBackendInterface) {
        return $backend->getStylePart($variables['part']);
      }
    }
  }

  return '';
}

/**
 * Sanitizes page metadata variables.
 */
function template_process_acton_head(&$variables) {
  // Validate creator email.
  if (!valid_email_address($variables['creator_address'])) {
    $variables['creator_address'] = '';
  }

  // Sanitize the rest.
  $clean = array('identifier', 'title', 'description', 'subject', 'date_modified', 'creator', 'creator_address');
  _acton_clean_variables($variables, $clean);
}

/**
 * Renders remote ANU header resources.
 */
function theme_acton_anu_head(&$variables) {
  return theme('acton_page_requisite', array(
    'part' => 'meta',
    'profile' => $variables['profile'],
  ));
}

/**
 * Renders page body banner.
 */
function theme_acton_anu_body_header(&$variables) {
  // Render page part.
  $profile = $variables['profile'];
  $banner = theme('acton_page_requisite', array(
    'part' => 'banner',
    'profile' => $variables['profile'],
  ));

  // Insert tabs if available.
  if ($variables['tabs']) {
    $controller = acton_profile_style_controller();
    if ($controller instanceof ActonProfileStyleCapabilitiesInterface && $capabilities = $controller->getCapabilities($profile)) {
      if ($capabilities->hasCapability(ActonProfileCapabilities::BANNER_TABS)) {
        $banner = str_replace('<!-- TABS -->', render($variables['tabs']), $banner);
      }
    }
  }

  return $banner;
}

/**
 * Renders page body footer.
 */
function theme_acton_anu_body_footer(&$variables) {
  return theme('acton_page_requisite', array(
    'part' => 'footer',
    'profile' => $variables['profile'],
  ));
}

/**
 * Prepares variables for search box.
 */
function template_preprocess_acton_search_box(&$variables) {
  // Prepare search scope.
  $bases = array();
  foreach ($variables['search_base'] as $base) {
    if ($base) {
      // Encode commas.
      $bases[] = str_replace(',', '%2C', $base);
    }
  }
  $scope = implode(',', $bases);

  $variables['scope_raw'] = $scope;
  $variables['scope'] = check_plain($scope);
  $variables['scope_query'] = check_plain(urlencode($scope));
}

/**
 * Sanitizes variables for search box.
 */
function template_process_acton_search_box(&$variables) {
  _acton_clean_variables($variables, array('site_short_name'));
}

/**
 * Adds horizontal banner tab behavior.
 */
function template_preprocess_acton_banner_tabs($variables) {
  drupal_add_js(drupal_get_path('module', 'acton_profile') . '/js/acton_banner_tabs.js');
}

/**
 * Prepares tab links for horizontal banner tabs.
 */
function template_process_acton_banner_tabs(&$variables) {
  // Process menu links into tab links.
  $variables['tab_links'] = array();
  foreach ($variables['links'] as $name => $link) {
    $link['acton_banner_tab'] = TRUE;
    $variables['tab_links'][$name] = l($link['title'], $link['href'], $link);
  }
}

/**
 * Prepares variables for the small search box.
 */
function template_preprocess_acton_search_box_mini(&$variables) {
  // Prepares search scope as regular search box.
  template_preprocess_acton_search_box($variables);
}

/**
 * Prepares variables for the site footer that precedes body footer.
 */
function template_preprocess_acton_site_footer(&$variables) {
  // Clean up site footer.
  if (valid_email_address($variables['resp_officer_address'])) {
    $variables['resp_officer_address'] = 'mailto:' . $variables['resp_officer_address'];
  }
  if (valid_email_address($variables['site_contact_address'])) {
    $variables['site_contact_address'] = 'mailto:' . $variables['site_contact_address'];
  }
}

/**
 * Finalizes variables for the site footer that precedes body footer.
 */
function template_process_acton_site_footer(&$variables) {
  $clean = array('resp_officer', 'resp_officer_address', 'site_contact', 'site_contact_address', 'date_modified');
  _acton_clean_variables($variables, $clean);

  // Populate site footer parts.
  $variables['parts'] = array();
  if ($variables['date_modified']) {
    $variables['parts']['date_modified'] = array(
      '#prefix' => '<span class="upd-date">',
      '#markup' => t('Updated:') . '&nbsp;&nbsp;<strong>' . $variables['date_modified'] . '</strong>',
      '#suffix' => '</span>',
    );
  }
  if ($variables['resp_officer'] && $variables['resp_officer_address']) {
    $variables['parts']['resp_officer'] = array(
      '#prefix' => '<span class="upd-officer">',
      '#markup' => t('Responsible Officer:') . '&nbsp;&nbsp;' . l('<strong>' . $variables['resp_officer'] . '</strong>', $variables['resp_officer_address'], array(
        'html' => TRUE,
        'external' => $variables['resp_officer_address'][0] == '/' ? TRUE : NULL,
      )),
      '#suffix' => '</span>',
    );
  }
  if ($variables['site_contact'] && $variables['site_contact_address']) {
    $variables['parts']['site_contact'] = array(
      '#prefix' => '<span class="upd-contact">',
      '#markup' => t('Page Contact:') . '&nbsp;&nbsp;' . l('<strong>' . $variables['site_contact'] . '</strong>', $variables['site_contact_address'], array(
        'html' => TRUE,
        'external' => $variables['site_contact_address'][0] == '/' ? TRUE : NULL,
      )),
      '#suffix' => '</span>',
    );
  }
}
